@@ -1,3 +1,8 @@
+""" Settings for core_oaipmh_provider_app
+
+Settings with the following syntax can be overwritten at the project level:
+SETTING_NAME = getattr(settings, "SETTING_NAME", "Default Value")
+"""
 from os.path import dirname, realpath
 
 from django.conf import settings
@@ -17,7 +22,7 @@ CUSTOM_NAME = getattr(settings, "CUSTOM_NAME", "")
 RESULTS_PER_PAGE = getattr(settings, "RESULTS_PER_PAGE", 10)
 
 # OAI_PMH parameters
-OAI_ADMINS = (("Administrator", "admin@curator.com"),)
+OAI_ADMINS = (("Administrator", "admin@example.com"),)
 OAI_HOST_URI = SERVER_URI
 OAI_NAME = CUSTOM_NAME + " OAI-PMH Server"
 OAI_DELIMITER = ":"
